TAMES SEARCH - Supreme Court
Author: Texas Office of Court Administration
Description: Case Mail case search
Keywords: Texas Court of Appeals CaseMail, CaseMail, Case Mail

Skip main navigation for Texas Court Online, go to main content navigation

Document Search |
--- | ---
Case Search Document Search
Step 1: Select the court(s) you want to search
All Courts |
Supreme Court | 3rd Court of Appeals | 7th Court of Appeals | 11th Court of Appeals
Court of Criminal Appeals | 4th Court of Appeals | 8th Court of Appeals | 12th Court of Appeals
1st Court of Appeals | 5th Court of Appeals | 9th Court of Appeals | 13th Court of Appeals
2nd Court of Appeals | 6th Court of Appeals | 10th Court of Appeals | 14th Court of Appeals
Step 2: Search by content of case Opinion, Order and/or Other
Search Text: | Stemming Phonic Fuzzy
From Date: |
7/8/2014 | Open the calendar popup.
<< | < | July 2014 | > | >>
| S | M | T | W | T | F | S
--- | --- | --- | --- | --- | --- | --- | ---
27 | 29 | 30 | 1 | 2 | 3 | 4 | 5
28 | 6 | 7 | 8 | 9 | 10 | 11 | 12
29 | 13 | 14 | 15 | 16 | 17 | 18 | 19
30 | 20 | 21 | 22 | 23 | 24 | 25 | 26
31 | 27 | 28 | 29 | 30 | 31 | 1 | 2
32 | 3 | 4 | 5 | 6 | 7 | 8 | 9
| To: |
7/8/2014 | Open the calendar popup.
<< | < | July 2014 | > | >>
| S | M | T | W | T | F | S
--- | --- | --- | --- | --- | --- | --- | ---
27 | 29 | 30 | 1 | 2 | 3 | 4 | 5
28 | 6 | 7 | 8 | 9 | 10 | 11 | 12
29 | 13 | 14 | 15 | 16 | 17 | 18 | 19
30 | 20 | 21 | 22 | 23 | 24 | 25 | 26
31 | 27 | 28 | 29 | 30 | 31 | 1 | 2
32 | 3 | 4 | 5 | 6 | 7 | 8 | 9
Select File(s) you want to search: | All Files |
Opinion | Order | Other
Examples: apple pie and pear | apple pie or pear | apple pie w/5 pear | apple not w/12 pear | apple and not pear | wildcard w/5 match* |
1 11 items in 1 pages
Hits | Date | Summary | Document Type | Case Number | Appellate Court
--- | --- | --- | --- | --- | ---
1 11 items in 1 pages
0 | 07/08/2014 |  | Opinion | 01-13-00674-CV | COA01
0 | 07/08/2014 |  | Opinion | 01-14-00533-CV | COA01
0 | 07/08/2014 |  | Opinion | 01-12-00971-CR | COA01
0 | 07/08/2014 |  | Opinion | 01-13-00933-CV | COA01
0 | 07/08/2014 |  | Opinion | 01-13-00581-CR | COA01
0 | 07/08/2014 |  | Opinion | 01-14-00369-CV | COA01
0 | 07/08/2014 |  | Opinion | 01-13-00631-CR | COA01
0 | 07/08/2014 |  | Opinion | 01-10-01153-CV | COA01
0 | 07/08/2014 |  | Order | 01-12-00215-CV | COA01
0 | 07/08/2014 |  | Order | 01-14-00116-CR | COA01
0 | 07/08/2014 |  | Order | 01-13-01027-CR | COA01
NOTE: This information is compiled and made available as a public service by The Supreme Court of Texas, the Texas Court of Criminal Appeals and the Courts of Appeals. However, these courts make no warranty as to the accuracy, reliability, or completeness of the information and are not responsible for any errors or omissions or for results obtained from the use of the information. Distribution of the information does not constitute such a warranty. Use of the information is the sole responsibility of the user. Also, note that neither TCO nor OCA have or maintain records on individual trial court cases but we maintain the following list of searchable county systems. You would need to contact the court DIRECTLY for specific case information, see our online Judicial Directory [or view pdf version] for contact information. To view or print PDF files you must have the Adobe Acrobat® reader. This software may be obtained without charge from Adobe. Download the reader from the Adobe Web site. | Skip main content navigation, go to main content #### General Information
| powered by |
Supreme Court Home Page Frequently Asked Questions Rules & Standards Orders & Opinions Clerk's Office About the Court Contact | Justices | Employment | History | Court News & Advisories | RSS Information | Podcasts | Court Calendar Permanent Judicial Commission for Children, Youth & Families #### Case Information Case Search Electronic Briefs Event Reports Oral Argument Information Oral Argument Audio Oral Argument Video Causes #### Case Mail Track Cases or Released Opinions My Account | Case Tracking | Opinion Tracking | Register | Basics | FAQs #### Texas Appellate Courts The Supreme Court of Texas Court of Criminal Appeals Courts of Appeals [by District-City] 1-Houston | 2-Fort Worth | 3-Austin 4-San Antonio | 5-Dallas | 6-Texarkana 7-Amarillo | 8-El Paso | 9-Beaumont 10-Waco | 11-Eastland | 12-Tyler 13-Corpus Christi/Edinburg 14-Houston Appellate Statistics